@@ -5,14 +5,13 @@ from .agent import (
     # create_planner_agent,
     get_model_name,
 )
-from .approval_hooks import ApprovalHooks, ToolApprovalError
+from .approval_hooks import ApprovalHooks
 from .hooks import ToolDisplayHooks, get_display_hooks
 
 __all__ = [
     "ToolDisplayHooks",
     "get_display_hooks",
     "ApprovalHooks",
-    "ToolApprovalError",
     # "create_planner_agent",
     "create_dev_agent",
     "get_model_name",
